/*
 *  Copyright 1997-2011 teatrove.org
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.teatrove.trove.classfile;

import java.io.*;

/**
 * This class corresponds to the cp_info structure as defined in
 * section 4.4 of <i>The Java Virtual Machine Specification</i>.
 * Subclasses should override the default hashCode and equals methods so
 * that the ConstantPool will only contain one instance of this constant.
 * 
 * @author Brian S O'Neill
 */
public abstract class ConstantInfo {
    final static int TAG_UTF8 = 1;
    final static int TAG_INTEGER = 3;
    final static int TAG_FLOAT = 4;
    final static int TAG_LONG = 5;
    final static int TAG_DOUBLE = 6;
    final static int TAG_CLASS = 7;
    final static int TAG_STRING = 8;
    final static int TAG_FIELD = 9;
    final static int TAG_METHOD = 10;
    final static int TAG_INTERFACE_METHOD = 11;
    final static int TAG_NAME_AND_TYPE = 12;

    // mIndex is manipulated by ConstantPool
    int mIndex = -1;
    private int mTag;
    
    protected ConstantInfo(int tag) {
        mTag = tag;
    }

    /**
     * The index of this constant in the constant pool. Is -1 if the
     * index has not yet been resolved. Constant pool indexes are resolved
     * when the constant pool is written out.
     */
    public int getIndex() {
        return mIndex;
    }

    boolean hasPriority() {
        return false;
    }
    
    int getEntryCount() {
        return 1;
    }

    public void writeTo(DataOutput dout) throws IOException {
        dout.writeByte(mTag);
    }
}
